@@ -85,7 +85,7 @@ AdaBoostModel <- function(
     },
 
     varimp = function(object, ...) {
-      object$importance
+      structure(object$importance, metric = "gini")
     }
 
   )
