@@ -25,8 +25,8 @@
 #'     data if different from the training set.}
 #' }
 #'
-#' Default values and further model details can be found in the source links
-#' below.
+#' Default argument values and further model details can be found in the source
+#' See Also links below.
 #'
 #' @return \code{MLModel} class object.
 #'
@@ -65,7 +65,8 @@ LDAModel <- function(
 
     fit = function(formula, data, weights, dimen, use, ...) {
       res <- MASS::lda(
-        formula, data = as.data.frame(formula, data), na.action = na.pass, ...
+        formula, data = as.data.frame(formula, data = data),
+        na.action = na.pass, ...
       )
       attr(res, ".MachineShop") <- list(
         dimen = if (missing(dimen)) length(res$svd) else dimen,
