@@ -28,24 +28,11 @@ setMethod(".append", c("data.frame", "data.frame"),
 )
 
 
-setMethod(".append", c("factor", "factor"),
-  function(x, y) unlist(list(x, y))
-)
-
-
 setMethod(".append", c("matrix", "matrix"),
   function(x, y) rbind(x, y)
 )
 
 
-setMethod(".append", c("ordered", "ordered"),
-  function(x, y) {
-    z <- unlist(list(x, y))
-    if (identical(levels(x), levels(y))) as.ordered(z) else z
-  }
-)
-
-
 setMethod(".append", c("SurvMatrix", "SurvMatrix"),
   function(x, y) c(x, y)
 )
