@@ -180,17 +180,18 @@ performance.BootOptimismControl <- function(x, resamples, ...) {
   resamples_split <- split(resamples, resamples$Iteration)
   for (name in names(resamples_split)) {
     resample <- resamples_split[[name]]
-    test_perf_list[[name]] <- performance(resample$Observed,
-                                          resample$Predicted,
-                                          resample$Weight, ...)
-    boot_perf_list[[name]] <- performance(resample$Boot.Observed,
-                                          resample$Boot.Predicted,
-                                          resample$Weight, ...)
+    test_perf_list[[name]] <- performance(
+      resample$Observed, resample$Predicted, resample$Weight, ...
+    )
+    boot_perf_list[[name]] <- performance(
+      resample$Boot.Observed, resample$Boot.Predicted, resample$Weight, ...
+    )
   }
   test_perf <- do.call(rbind, test_perf_list)
   boot_perf <- do.call(rbind, boot_perf_list)
-  train_perf <- performance(resample$Observed, resample$Train.Predicted,
-                            resample$Weight, ...)
+  train_perf <- performance(
+    resample$Observed, resample$Train.Predicted, resample$Weight, ...
+  )
 
   pessimism <- test_perf - boot_perf
   sweep(pessimism, 2, train_perf, "+")
@@ -211,9 +212,10 @@ performance.CVOptimismControl <- function(x, resamples, ...) {
     Reduce("+", map(f, props, preds))
   }, resamples_split)
   cv_perf <- do.call(rbind, rep(perf_list, each = x@folds))
-  train_perf <- performance(resamples_split[[1]]$Observed,
-                            resamples_split[[1]]$Train.Predicted,
-                            resamples_split[[1]]$Weight, ...)
+  train_perf <- performance(
+    resamples_split[[1]]$Observed, resamples_split[[1]]$Train.Predicted,
+    resamples_split[[1]]$Weight, ...
+  )
 
   pessimism <- test_perf - cv_perf
   sweep(pessimism, 2, train_perf, "+")
