@@ -41,6 +41,9 @@
 #' \code{\link[recipes]{prep}}, \code{\link[recipes]{bake}}
 #'
 #' @examples
+#' \donttest{
+#' ## Requires prior installation of suggested package elasticnet to run
+#'
 #' library(recipes)
 #'
 #' rec <- recipe(rating ~ ., data = attitude)
@@ -53,6 +56,7 @@
 #'
 #' tidy(spca_rec, number = 1)
 #' tidy(spca_prep, number = 1)
+#' }
 #'
 step_spca <- function(
   recipe, ..., num_comp = 5, sparsity = 0, num_var = integer(),
@@ -81,8 +85,7 @@ step_spca <- function(
 }
 
 
-new_step_spca <- function(..., sparsity, num_var, shrinkage, max_iter,
-                          tol) {
+new_step_spca <- function(..., sparsity, num_var, shrinkage, max_iter, tol) {
 
   throw(check_packages("elasticnet"))
 
@@ -98,10 +101,10 @@ new_step_spca <- function(..., sparsity, num_var, shrinkage, max_iter,
       para <- step$num_var
       sparse <- "varnum"
     }
-    res <- elasticnet::spca(x, K = num_comp,
-                            para = rep_len(para, num_comp),
-                            sparse = sparse, lambda = step$shrinkage,
-                            max.iter = step$max_iter, eps.conv = step$tol)
+    res <- elasticnet::spca(
+      x, K = num_comp, para = rep_len(para, num_comp), sparse = sparse,
+      lambda = step$shrinkage, max.iter = step$max_iter, eps.conv = step$tol
+    )
 
     list(weights = res$loadings, pev = res$pev)
 
